WidgetRecorderController class
Controller for recording widget
- Mixed-in types
Constructors
- WidgetRecorderController({required int targetFps, bool isWithTicker = false})
Properties
- frameInterval → Duration
-
Interval between frames.
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
- hasListeners → bool
-
Whether any listeners are currently registered.
no setterinherited
- isRecording → bool
-
Whether the recording is in progress.
no setter
- isWithTicker → bool
-
final
- path → String?
-
Path to the recorded video.
no setter
-
repaintKey
→ GlobalKey<
State< StatefulWidget> > -
Global key to the widget to be recorded.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
addListener(
VoidCallback listener) → void -
Register a closure to be called when the object changes.
inherited
-
dispose(
) → void -
Discards any resources used by the object.
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
notifyListeners(
) → void -
Call all the registered listeners.
inherited
-
removeListener(
VoidCallback listener) → void -
Remove a previously registered closure from the list of closures that are
notified when the object changes.
inherited
-
startRecording(
String name, {required double pixelRatio}) → Future< void> - Start recording. Pass devicePixelRatio explicitly here.
-
stopRecording(
) → Future< void> - Stop recording.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited